#!/bin/bash

BASE_APM_PATH="/opt/datadog/apm"
BINARY_INSTALL_PATH="$BASE_APM_PATH/inject"
LIBRARIES_INSTALL_BASE="$BASE_APM_PATH/library"
UNIX_DOMAIN_SOCKET_PATH_DIR="$BINARY_INSTALL_PATH/run"
UNIX_DOMAIN_SOCKET_PATH="$UNIX_DOMAIN_SOCKET_PATH_DIR/apm.socket"
DOGSTATSD_SOCKET_PATH="$UNIX_DOMAIN_SOCKET_PATH_DIR/dsd.socket"

# Root user detection
if [[ $UID = "0" ]]; then
    sudo_cmd=''
else
    sudo_cmd='sudo'
fi

function service_control() {
  action=$1
  service_name=$2


  # Service command discovery. Copied from https://github.com/DataDog/agent-linux-install-script/blob/f8471b2c27c4c7a98f16b851aedb70e9c4c54a1c/install_script.sh.template#LL791-L812C3
  service_cmd="service"
  if [[ $SUSE11 = "yes" ]]; then
    service_cmd=$($sudo_cmd which service)
  fi

  # Use /usr/sbin/service by default.
  # Some distros usually include compatibility scripts with Upstart or Systemd. Check with: `command -v service | xargs grep -E "(upstart|systemd)"`
  restart_cmd="$sudo_cmd $service_cmd $service_name restart"
  reload_cmd="$sudo_cmd $service_cmd $service_name reload"

  if [[ $($sudo_cmd ps --no-headers -o comm 1 2>&1) == "systemd" ]] && command -v systemctl 2>&1; then
    # Use systemd if systemctl binary exists and systemd is the init process
    restart_cmd="$sudo_cmd systemctl restart ${service_name}.service"
    reload_cmd="$sudo_cmd systemctl reload ${service_name}.service"
  elif /sbin/init --version 2>&1 | grep -q upstart; then
    # Try to detect Upstart, this works most of the times but still a best effort
    restart_cmd="$sudo_cmd stop $service_name || true ; sleep 2s ; $sudo_cmd start $system_service"
    reload_cmd=$restart_cmd
  fi

  if [[ "restart" = "$action" ]]; then
    printf "\033[34m* Restarting %s...\n\033[0m\n" "$service_name"
    eval "$restart_cmd"
  else
    printf "\033[34m* Reloading %s...\n\033[0m\n" "$service_name"
    eval "$reload_cmd"
  fi

}


# Parse command line args
while [[ $# -gt 0 ]]; do
    case $1 in
        -h|--help)
            usage
            exit 0
            ;;
        --uninstall)
            uninstall_flag="true"
            shift
            ;;
        --no-config-change)
            no_config_change="true"
            shift
            ;;
        --no-agent-restart)
            no_agent_restart="true"
            shift
            ;;
        --no-docker-reload)
            no_docker_reload="true"
            shift
            ;;
        *)
            echo -e "ERROR: An unknown flag was passed: ${1}\n"
            usage
            no_agent_restart="true"
            no_docker_reload="true"
            shift
            ;;
    esac
done
